package sample;

import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.mock.jndi.SimpleNamingContextBuilder;

import com.mchange.v2.c3p0.DriverManagerDataSource;

public class JndiMain {
    
    public static void main(String[] args) throws Exception {
    	// データソースのオブジェクトを生成
        DriverManagerDataSource ds = new DriverManagerDataSource();
        ds.setDriverClass("org.hsqldb.jdbc.JDBCDriver");
        ds.setJdbcUrl("jdbc:hsqldb:hsql://localhost/sample");
        ds.setUser("sa");
        ds.setPassword("");

        // Springが提供するJNDI実装(テスト用)を使用し、ネーミングコンテキストを生成
        SimpleNamingContextBuilder builder = new SimpleNamingContextBuilder();
        builder.bind("jdbc/MyDataSource", ds);
        builder.activate();
        
        // Bean定義ファイルを使用し、JNDI経由でデータソースを取得
        ApplicationContext ctx = new ClassPathXmlApplicationContext("spring-jndi.xml");
        JdbcTemplate jdbcTemplate = ctx.getBean(JdbcTemplate.class);
        
        int count = jdbcTemplate.queryForInt("SELECT COUNT(*) FROM PET");
        System.out.println(count);
        
        // アノテーションを使用し、JNDI経由でデータソースを取得
        JndiAnnotationSample sample = ctx.getBean(JndiAnnotationSample.class);
        sample.printDataSource();
    }
}
